@@ -12,9 +12,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from testtools import testcase as tc
+
+from tempest.lib import decorators
+from tempest.lib.common.utils import data_utils
+
 from sahara_tempest_plugin.tests.api import base as dp_base
-from tempest.common.utils import data_utils
-from tempest import test
 
 
 class JobBinaryInternalTest(dp_base.BaseDataProcessingTest):
@@ -46,13 +49,13 @@ class JobBinaryInternalTest(dp_base.BaseDataProcessingTest):
 
         return resp_body['id'], binary_name
 
-    @test.attr(type='smoke')
-    @test.idempotent_id('249c4dc2-946f-4939-83e6-212ddb6ea0be')
+    @tc.attr('smoke')
+    @decorators.idempotent_id('249c4dc2-946f-4939-83e6-212ddb6ea0be')
     def test_job_binary_internal_create(self):
         self._create_job_binary_internal()
 
-    @test.attr(type='smoke')
-    @test.idempotent_id('1e3c2ecd-5673-499d-babe-4fe2fcdf64ee')
+    @tc.attr('smoke')
+    @decorators.idempotent_id('1e3c2ecd-5673-499d-babe-4fe2fcdf64ee')
     def test_job_binary_internal_list(self):
         binary_info = self._create_job_binary_internal()
 
@@ -61,8 +64,8 @@ class JobBinaryInternalTest(dp_base.BaseDataProcessingTest):
         binaries_info = [(binary['id'], binary['name']) for binary in binaries]
         self.assertIn(binary_info, binaries_info)
 
-    @test.attr(type='smoke')
-    @test.idempotent_id('a2046a53-386c-43ab-be35-df54b19db776')
+    @tc.attr('smoke')
+    @decorators.idempotent_id('a2046a53-386c-43ab-be35-df54b19db776')
     def test_job_binary_internal_get(self):
         binary_id, binary_name = self._create_job_binary_internal()
 
@@ -70,8 +73,8 @@ class JobBinaryInternalTest(dp_base.BaseDataProcessingTest):
         binary = self.client.get_job_binary_internal(binary_id)
         self.assertEqual(binary_name, binary['job_binary_internal']['name'])
 
-    @test.attr(type='smoke')
-    @test.idempotent_id('b3568c33-4eed-40d5-aae4-6ff3b2ac58f5')
+    @tc.attr('smoke')
+    @decorators.idempotent_id('b3568c33-4eed-40d5-aae4-6ff3b2ac58f5')
     def test_job_binary_internal_delete(self):
         binary_id, _ = self._create_job_binary_internal()
 
@@ -85,8 +88,8 @@ class JobBinaryInternalTest(dp_base.BaseDataProcessingTest):
         binaries_ids = [binary['id'] for binary in binaries]
         self.assertNotIn(binary_id, binaries_ids)
 
-    @test.attr(type='smoke')
-    @test.idempotent_id('8871f2b0-5782-4d66-9bb9-6f95bcb839ea')
+    @tc.attr('smoke')
+    @decorators.idempotent_id('8871f2b0-5782-4d66-9bb9-6f95bcb839ea')
     def test_job_binary_internal_get_data(self):
         binary_id, _ = self._create_job_binary_internal()
 
