@@ -25,6 +25,7 @@ TEMPEST_CONF = config.CONF
 DEL_RESULT = '''\
 {} "{}" has been removed successfully.
 '''
+TEMPEST_ERROR_MESSAGE = 'No matches found.'
 
 
 class ClientTestBase(base.ClientTestBase):
@@ -83,6 +84,12 @@ class ClientTestBase(base.ClientTestBase):
         # have the first letter capitalized.
         self.assertEqual(delete_cmd.lower(), result.lower())
 
+    def delete_resource(self, command, name):
+        list_of_resources = self.listing_result('%s list' % command)
+        list_of_resource_names = [r['Name'] for r in list_of_resources]
+        if name in list_of_resource_names:
+            self.openstack('dataprocessing %s delete' % command, params=name)
+
     def get_default_plugin(self):
         plugins = self.listing_result('plugin list')
         default_plugin_name = plugin_utils.get_default_plugin()
@@ -101,8 +108,7 @@ class ClientTestBase(base.ClientTestBase):
 
     def _get_cluster_status(self, cluster_name):
         status = None
-        show_cluster = self.listing_result(''.join(['cluster show ',
-                                                    cluster_name]))
+        show_cluster = self.listing_result('cluster show %s' % cluster_name)
         for line in show_cluster:
             if line['Field'] == 'Status':
                 status = line['Value']
@@ -111,6 +117,17 @@ class ClientTestBase(base.ClientTestBase):
                                      'status')
         return status
 
+    def _get_resource_id(self, resource, resource_name):
+        resource_id = None
+        show_resource = self.listing_result('%s show %s'
+                                            % (resource, resource_name))
+        for line in show_resource:
+            if line['Field'] == 'Id':
+                resource_id = line['Value']
+        if resource_id is None:
+            raise self.skipException('No such %s exists' % resource)
+        return resource_id
+
     def _poll_cluster_status(self, cluster_name):
         with fixtures.Timeout(TEMPEST_CONF.data_processing.cluster_timeout,
                               gentle=True):
@@ -128,10 +145,30 @@ class ClientTestBase(base.ClientTestBase):
         # if name exists in the command "type list" than tests should fail
         with fixtures.Timeout(300, gentle=True):
             while True:
-                list_of_types = self.listing_result(''.join([type, ' list']))
+                list_of_types = self.listing_result('%s list' % type)
                 list_names = [p['Name'] for p in list_of_types]
-                for resource_name in list_names:
-                    if resource_name == name:
-                        name_exist = True
+                if name in list_names:
+                    name_exist = True
                 if not name_exist:
                     break
+
+    def check_negative_scenarios(self, error_message, cmd, name):
+        msg_exist = None
+        try:
+            self.openstack('dataprocessing %s' % cmd, params=name)
+        except exc.CommandFailed as e:
+            # lower() is required because "result" string could
+            # have the first letter capitalized.
+            output_msg = str(e).splitlines()
+            for msg in output_msg:
+                if msg.lower() == error_message.lower():
+                    self.assertEqual(error_message.lower(), msg.lower())
+                    msg_exist = True
+            if not msg_exist:
+                raise exc.TempestException('%s is not a part of output of '
+                                           'executed command %s'
+                                           % (error_message, cmd))
+        else:
+            raise exc.TempestException('%s %s in negative scenarios have been '
+                                       'executed without any errors'
+                                       % (cmd, name))
